| arrow_radius | R Documentation |
Returns the distance from arrow tip to base midpoint. This is how far back from the tip the arrow extends.
arrow_radius(size, arrow_angle = pi/6)
size |
Arrow size in user coordinates. |
arrow_angle |
Arrow head angle in radians. Default pi/6 (30 degrees). |
The arrow radius (distance from tip to base).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.