| centrality_kreach | R Documentation |
Count of nodes reachable within shortest path distance k. Measures
how many nodes a given node can reach quickly.
centrality_kreach(x, mode = "all", k = 3, ...)
x |
Network input (matrix, igraph, network, cograph_network, tna object). |
mode |
For directed networks: |
k |
Maximum path length. Default 3. |
... |
Additional arguments passed to |
Named numeric vector of k-reach centrality values.
centrality for computing multiple measures at once.
adj <- matrix(c(0, 1, 0, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 0, 1, 0), 4, 4)
rownames(adj) <- colnames(adj) <- c("A", "B", "C", "D")
centrality_kreach(adj, k = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.