draw_donut_pie: Draw Donut with Inner Pie Node

View source: R/shapes-special.R

draw_donut_pieR Documentation

Draw Donut with Inner Pie Node

Description

Draw a node with an outer donut ring showing a proportion and an inner pie chart with multiple segments.

Usage

draw_donut_pie(
  x,
  y,
  size,
  fill,
  border_color,
  border_width,
  alpha = 1,
  donut_value = NULL,
  pie_values = NULL,
  pie_colors = NULL,
  inner_ratio = 0.5,
  bg_color = "gray90",
  pie_border_width = NULL,
  donut_border_width = NULL,
  ...
)

Arguments

pie_border_width

Border width for pie segments (optional).

donut_border_width

Border width for donut ring (optional).


cograph documentation built on April 1, 2026, 1:07 a.m.