Learn R Programming

cograph (version 1.5.2)

find_curve_split_index: Find Split Index for Curve Based on Arc Length Fraction

Description

Calculates the index at which to split a curve's coordinate arrays so that the first segment covers a given fraction of the total arc length.

Usage

find_curve_split_index(x, y, fraction)

Value

Index at which to split the arrays.

Arguments

x, y

Vectors of curve coordinates.

fraction

Desired fraction of total arc length (0-1).