View source: R/splot-polygons.R
| inset_polygon_vertices | R Documentation |
Creates an inner polygon by scaling vertices toward the centroid.
inset_polygon_vertices(outer, inner_ratio)
outer |
List with x, y vectors of outer polygon vertices. |
inner_ratio |
Ratio to scale vertices toward center (0-1). |
List with x, y vectors of inner polygon vertices.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.