map_qgraph_lty: Map qgraph lty codes to cograph edge style names

View source: R/from-qgraph.R

map_qgraph_ltyR Documentation

Map qgraph lty codes to cograph edge style names

Description

Map qgraph lty codes to cograph edge style names

Usage

map_qgraph_lty(lty)

Arguments

lty

Numeric or character vector of R line types

Value

Character vector of cograph style names


cograph documentation built on April 1, 2026, 1:07 a.m.