| parse_input | R Documentation |
Automatically detects input type and converts to internal format.
parse_input(input, directed = NULL, simplify = FALSE)
input |
Network input: matrix, data.frame (edge list), igraph, statnet
network, qgraph, tna, or an already-parsed list with an |
directed |
Logical. Force directed interpretation. NULL for auto-detect. |
simplify |
Logical or character. Passed to |
List with parsed network components, usually including nodes, edges, directed, and weight information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.