View source: R/fit-distribution.R
| plot.cograph_degree_fit | R Documentation |
Overlays fitted distribution curves on a histogram of observed degrees.
## S3 method for class 'cograph_degree_fit'
plot(
x,
which = NULL,
log = "",
cols = NULL,
lwd = 2,
main = "Degree Distribution Fit",
...
)
x |
A |
which |
Character vector of distribution names to display. Default
|
log |
Character string for log-scale axes: |
cols |
Named or unnamed character vector of colors for distribution curves. Default uses a built-in palette. |
lwd |
Line width for fitted curves. Default 2. |
main |
Plot title. Default |
... |
Additional arguments passed to |
Invisible NULL.
adj <- matrix(c(0, 1, 1, 0, 0, 1, 0, 1, 1, 0,
1, 1, 0, 1, 1, 0, 1, 1, 0, 1,
0, 0, 1, 1, 0), 5, 5, byrow = TRUE)
fit <- cograph::fit_degree_distribution(adj)
plot(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.