| rich_club_local | R Documentation |
For each node, measures whether it preferentially directs its strongest ties toward prominent nodes. A score > 1 means the node's ties to prominent nodes are stronger than average.
rich_club_local(
x,
prominence = NULL,
rich = c("k", "s"),
directed = NULL,
digits = NULL,
sort_by = "score",
...
)
x |
Network input: matrix, igraph, network, cograph_network, or tna object. |
prominence |
Integer or logical vector indicating which nodes are prominent (1/TRUE = prominent), OR a numeric threshold. If NULL, nodes above median degree (or strength) are prominent. |
rich |
Character. |
directed |
Logical or NULL. Default NULL (auto-detect). |
digits |
Integer or NULL. Round scores. Default NULL. |
sort_by |
Character or NULL. Column to sort by (descending). Default
|
... |
Additional arguments passed to |
For each node i: r_i = \bar{w}_{i \to rich} / \bar{w}_i
A data frame with columns node and score, sorted
by score descending. Values > 1 indicate the node directs
disproportionately strong ties to prominent nodes.
Opsahl, T., Colizza, V., Panzarasa, P. & Ramasco, J.J. (2008). Prominence and control: The weighted rich-club effect. Physical Review Letters, 101, 168702.
rich_club, centrality
adj <- matrix(c(0,5,3,1, 5,0,4,2, 3,4,0,1, 1,2,1,0), 4, 4)
rownames(adj) <- colnames(adj) <- c("A", "B", "C", "D")
cograph::rich_club_local(adj, prominence = c(1, 1, 0, 0))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.