Learn R Programming

cograph (version 1.5.2)

arrow_base_midpoint: Calculate Arrow Base Midpoint

Description

Returns the midpoint between the arrow wings (where the curve should end). This is used to connect the edge line to the back of the arrow head.

Usage

arrow_base_midpoint(x, y, angle, size, arrow_angle = pi/6)

Value

List with x, y coordinates of the arrow base midpoint.

Arguments

x

Arrow tip x coordinate.

y

Arrow tip y coordinate.

angle

Angle of incoming edge (radians).

size

Arrow size in user coordinates.

arrow_angle

Arrow head angle in radians. Default pi/6 (30 degrees).