Returns the midpoint between the arrow wings (where the curve should end). This is used to connect the edge line to the back of the arrow head.
arrow_base_midpoint(x, y, angle, size, arrow_angle = pi/6)List with x, y coordinates of the arrow base midpoint.
Arrow tip x coordinate.
Arrow tip y coordinate.
Angle of incoming edge (radians).
Arrow size in user coordinates.
Arrow head angle in radians. Default pi/6 (30 degrees).