Learn R Programming

cograph (version 1.5.2)

arrow_radius: Calculate Arrow Radius

Description

Returns the distance from arrow tip to base midpoint. This is how far back from the tip the arrow extends.

Usage

arrow_radius(size, arrow_angle = pi/6)

Value

The arrow radius (distance from tip to base).

Arguments

size

Arrow size in user coordinates.

arrow_angle

Arrow head angle in radians. Default pi/6 (30 degrees).