| centrality_closeness_vitality | R Documentation |
Drop in the Wiener index when a node is removed. Higher values indicate more critical nodes for overall connectivity.
centrality_closeness_vitality(x, mode = "all", ...)
x |
Network input (matrix, igraph, network, cograph_network, tna object). |
mode |
For directed networks: |
... |
Additional arguments passed to |
Named numeric vector of closeness vitality values.
centrality for computing multiple measures at once.
adj <- matrix(c(0, 1, 0, 1, 0, 1, 0, 1, 0), 3, 3)
rownames(adj) <- colnames(adj) <- c("A", "B", "C")
centrality_closeness_vitality(adj)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.