| centrality_leverage | R Documentation |
Measures a node's influence over its neighbors based on relative degree differences. Positive values indicate the node has more connections than its average neighbor.
centrality_leverage(x, mode = "all", ...)
x |
Network input (matrix, igraph, network, cograph_network, tna object). |
mode |
For directed networks: |
... |
Additional arguments passed to |
Named numeric vector of leverage centrality values (range -1 to 1).
centrality for computing multiple measures at once.
adj <- matrix(c(0, 1, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 1, 0, 0), 4, 4)
rownames(adj) <- colnames(adj) <- c("A", "B", "C", "D")
centrality_leverage(adj)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.