| centrality_load | R Documentation |
Fraction of all shortest paths passing through a node, similar to betweenness but weighting paths by 1/count (Goh et al. 2001).
centrality_load(x, ...)
x |
Network input (matrix, igraph, network, cograph_network, tna object). |
... |
Additional arguments passed to |
Named numeric vector of load centrality values.
centrality for computing multiple measures at once,
centrality_betweenness for the standard variant.
adj <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), 3, 3)
rownames(adj) <- colnames(adj) <- c("A", "B", "C")
centrality_load(adj)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.