Learn R Programming

cograph (version 2.0.0)

centrality_load: Load Centrality

Description

Fraction of all shortest paths passing through a node, similar to betweenness but weighting paths by 1/count (Goh et al. 2001).

Usage

centrality_load(x, ...)

Value

Named numeric vector of load centrality values.

Arguments

x

Network input (matrix, igraph, network, cograph_network, tna object).

...

Additional arguments passed to centrality (e.g., weighted, directed).

See Also

centrality for computing multiple measures at once, centrality_betweenness for the standard variant.

Examples

Run this code
adj <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), 3, 3)
rownames(adj) <- colnames(adj) <- c("A", "B", "C")
centrality_load(adj)

Run the code above in your browser using DataLab