powered by
Fraction of all shortest paths passing through a node, similar to betweenness but weighting paths by 1/count (Goh et al. 2001).
centrality_load(x, ...)
Named numeric vector of load centrality values.
Network input (matrix, igraph, network, cograph_network, tna object).
Additional arguments passed to centrality (e.g., weighted, directed).
centrality
weighted
directed
centrality for computing multiple measures at once, centrality_betweenness for the standard variant.
centrality_betweenness
adj <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), 3, 3) rownames(adj) <- colnames(adj) <- c("A", "B", "C") centrality_load(adj)
Run the code above in your browser using DataLab