powered by
Random walk centrality measuring node importance. Simulates a random walker that follows edges with probability damping and jumps to a random node with probability 1 - damping.
damping
1 - damping
centrality_pagerank(x, damping = 0.85, personalized = NULL, ...)
Named numeric vector of PageRank values.
Network input (matrix, igraph, network, cograph_network, tna object).
Damping factor (probability of following an edge). Default 0.85.
Named numeric vector for personalized PageRank. Values should sum to 1. Default NULL (uniform).
NULL
Additional arguments passed to centrality (e.g., weighted, directed).
centrality
weighted
directed
centrality for computing multiple measures at once, centrality_eigenvector for a related measure.
centrality_eigenvector
adj <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), 3, 3) rownames(adj) <- colnames(adj) <- c("A", "B", "C") centrality_pagerank(adj) centrality_pagerank(adj, damping = 0.9)
Run the code above in your browser using DataLab