Learn R Programming

cograph (version 2.7.2)

centrality_pairwisedis: Pairwise Disconnectivity (Potapov et al. 2008)

Description

For a directed network, pairwisedis(v) is the fraction of ordered reachable pairs \((s, t)\) that become unreachable when node \(v\) is removed: $$PD(v) = (|P(G)| - |P(G - v)|) / |P(G)|$$ where \(|P(G)|\) is the number of ordered pairs \((s, t), s \ne t\) with a directed path from \(s\) to \(t\).

Usage

centrality_pairwisedis(x, ...)

Value

Named numeric vector of pairwise disconnectivity values in \([0, 1]\).

Arguments

x

Directed network input (matrix, igraph, cograph_network, tna object).

...

Additional arguments passed to centrality.

Details

Bit-exact match against centiserve::pairwisedis on directed graphs. Requires the input to be directed; returns NA with a warning on undirected inputs.

References

Potapov, A. P., Goemann, B., & Wingender, E. (2008). The pairwise disconnectivity index as a new metric for the topological analysis of regulatory networks. BMC Bioinformatics, 9, 227. tools:::Rd_expr_doi("10.1186/1471-2105-9-227").

See Also

centrality, robustness.

Examples

Run this code
adj <- matrix(c(0,1,0, 0,0,1, 1,0,0), 3, 3, byrow = TRUE)
rownames(adj) <- colnames(adj) <- c("A", "B", "C")
centrality_pairwisedis(adj)

Run the code above in your browser using DataLab