Learn R Programming

cograph (version 2.0.0)

check_duplicate_edges: Check and Handle Duplicate Edges

Description

Detects duplicate edges in undirected networks and either errors with guidance or aggregates them per the user's edge_duplicates setting.

Usage

check_duplicate_edges(edges, directed, edge_duplicates)

Value

Possibly aggregated edge data frame.

Arguments

edges

Edge data frame.

directed

Logical: is the network directed?

edge_duplicates

Aggregation method (NULL to error, or "sum"/"mean"/etc).