A modern, extensible network visualization package that provides high-quality static and interactive network plots. cograph accepts adjacency matrices, edge lists, or igraph objects and offers customizable layouts, node shapes, edge styles, and themes.
cograph: Main entry point for creating network visualizations
sn_layout: Apply layout algorithms
sn_nodes: Customize node aesthetics
sn_edges: Customize edge aesthetics
sn_theme: Apply visual themes
sn_render: Render to device
sn_ggplot: Convert to ggplot2 object
cograph provides several built-in layouts:
circle: Nodes arranged in a circle
spring: Fruchterman-Reingold force-directed layout
groups: Group-based circular layout
custom: User-provided coordinates
Built-in themes include:
classic: Traditional network visualization style
colorblind: Accessible color scheme
gray: Grayscale theme
dark: Dark background theme
minimal: Clean, minimal style
Maintainer: Sonsoles López-Pernas sonsoles.lopez@uef.fi
Authors:
Mohammed Saqr
Santtu Tikka
Useful links: