Draws an arrow head at the end of a curved edge, with angle following the curve direction.
draw_curved_arrow_base(
spline_x,
spline_y,
size,
arrow_angle = pi/6,
col = "black",
border = NULL
)X coordinates of the spline.
Y coordinates of the spline.
Arrow size.
Arrow head angle in radians. Default pi/6 (30 degrees).
Arrow fill color.
Arrow border color.