View source: R/shapes-special.R
| draw_donut_pie | R Documentation |
Draw a node with an outer donut ring showing a proportion and an inner pie chart with multiple segments.
draw_donut_pie(
x,
y,
size,
fill,
border_color,
border_width,
alpha = 1,
donut_value = NULL,
pie_values = NULL,
pie_colors = NULL,
inner_ratio = 0.5,
bg_color = "gray90",
pie_border_width = NULL,
donut_border_width = NULL,
...
)
pie_border_width |
Border width for pie segments (optional). |
donut_border_width |
Border width for donut ring (optional). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.