Draw a node with an outer donut ring showing a proportion and an inner pie chart with multiple segments.
draw_donut_pie(
x,
y,
size,
fill,
border_color,
border_width,
alpha = 1,
donut_value = NULL,
pie_values = NULL,
pie_colors = NULL,
inner_ratio = 0.5,
bg_color = "gray90",
pie_border_width = NULL,
donut_border_width = NULL,
...
)Border width for pie segments (optional).
Border width for donut ring (optional).