| find_curve_split_index | R Documentation |
Calculates the index at which to split a curve's coordinate arrays so that the first segment covers a given fraction of the total arc length.
find_curve_split_index(x, y, fraction)
x, y |
Vectors of curve coordinates. |
fraction |
Desired fraction of total arc length (0-1). |
Index at which to split the arrays.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.