get_nodes: Get Nodes from Cograph Network

View source: R/class-network.R

get_nodesR Documentation

Get Nodes from Cograph Network

Description

Extracts the nodes data frame from a cograph_network object.

Usage

get_nodes(x)

Arguments

x

A cograph_network object.

Value

A node metadata data frame, usually with id and label columns, plus layout or other metadata columns when present.

See Also

as_cograph, n_nodes, get_edges

Examples

mat <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), nrow = 3)
net <- as_cograph(mat)
get_nodes(net)

cograph documentation built on May 31, 2026, 5:06 p.m.