Learn R Programming

cograph (version 2.7.2)

get_nodes: Get Nodes from Cograph Network

Description

Extracts the nodes data frame from a cograph_network object.

Usage

get_nodes(x)

Value

A node metadata data frame, usually with id and label

columns, plus layout or other metadata columns when present.

Arguments

x

A cograph_network object.

See Also

as_cograph, n_nodes, get_edges

Examples

Run this code
mat <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), nrow = 3)
net <- as_cograph(mat)
get_nodes(net)

Run the code above in your browser using DataLab