powered by
Extracts the nodes data frame from a cograph_network object.
get_nodes(x)
A node metadata data frame, usually with id and label
id
label
columns, plus layout or other metadata columns when present.
A cograph_network object.
as_cograph, n_nodes, get_edges
as_cograph
n_nodes
get_edges
mat <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), nrow = 3) net <- as_cograph(mat) get_nodes(net)
Run the code above in your browser using DataLab