Learn R Programming

cograph (version 1.5.2)

map_qgraph_lty: Map qgraph lty codes to cograph edge style names

Description

Map qgraph lty codes to cograph edge style names

Usage

map_qgraph_lty(lty)

Value

Character vector of cograph style names

Arguments

lty

Numeric or character vector of R line types