| mutate_edges | R Documentation |
Add or Change Edge Attributes
mutate_edges(
x,
...,
community = "louvain",
keep_format = FALSE,
directed = NULL
)
x |
Network input. |
... |
Named expressions evaluated against the edge table, with the same
metrics and predicates |
community |
Community detection method used when an expression refers
to |
keep_format |
Logical. Return the input format when TRUE. |
directed |
Logical or NULL. If NULL (default), auto-detect. |
A cograph_network whose edge table has the new columns, or
the input format when keep_format = TRUE.
mutate_nodes, select_edges
adj <- matrix(c(0, .5, .8, 0,
.5, 0, .3, .6,
.8, .3, 0, .4,
0, .6, .4, 0), 4, 4, byrow = TRUE)
rownames(adj) <- colnames(adj) <- c("A", "B", "C", "D")
as.data.frame(mutate_edges(adj, strong = weight > 0.5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.