View source: R/class-network.R
| nodes | R Documentation |
Extracts the nodes data frame from a cograph_network object.
Deprecated: Use get_nodes instead.
nodes(x)
x |
A cograph_network object. |
A node metadata data frame, usually with id and label
columns, plus layout or other metadata columns when present.
get_nodes, as_cograph, n_nodes
mat <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), nrow = 3)
net <- as_cograph(mat)
nodes(net) # Deprecated, use get_nodes(net) instead
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.