powered by
Extracts the nodes data frame from a cograph_network object. Deprecated: Use get_nodes instead.
get_nodes
nodes(x)
A node metadata data frame, usually with id and label
id
label
columns, plus layout or other metadata columns when present.
A cograph_network object.
get_nodes, as_cograph, n_nodes
as_cograph
n_nodes
mat <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), nrow = 3) net <- as_cograph(mat) nodes(net) # Deprecated, use get_nodes(net) instead
Run the code above in your browser using DataLab