| register_layout | R Documentation |
Register a new layout algorithm that can be used for network visualization.
register_layout(name, layout_fn)
name |
Character. Name of the layout. |
layout_fn |
Function. A function that computes node positions. Should accept a CographNetwork object and return a matrix with x, y columns. |
Invisible NULL.
# Register a simple random layout
register_layout("random", function(network, ...) {
n <- network$n_nodes
cbind(x = runif(n), y = runif(n))
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.