Learn R Programming

cograph (version 1.5.2)

register_layout: Register a Custom Layout

Description

Register a new layout algorithm that can be used for network visualization.

Usage

register_layout(name, layout_fn)

Value

Invisible NULL.

Arguments

name

Character. Name of the layout.

layout_fn

Function. A function that computes node positions. Should accept a CographNetwork object and return a matrix with x, y columns.

Examples

Run this code
# Register a simple random layout
register_layout("random", function(network, ...) {
  n <- network$n_nodes
  cbind(x = runif(n), y = runif(n))
})

Run the code above in your browser using DataLab