Learn R Programming

cograph (version 2.7.2)

remove_nodes: Remove Nodes from a Network

Description

Remove Nodes from a Network

Usage

remove_nodes(x, nodes, keep_format = FALSE, directed = NULL)

Value

A cograph_network without those nodes and without any edge that touched them, or the input format when keep_format = TRUE.

Arguments

x

Network input.

nodes

Node labels or indices to remove.

keep_format

Logical. Return the input format when TRUE.

directed

Logical or NULL. If NULL (default), auto-detect.

See Also

add_nodes, filter_nodes, remove_isolates

Examples

Run this code
adj <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), 3, 3)
rownames(adj) <- colnames(adj) <- c("A", "B", "C")

remove_nodes(adj, nodes = "B")

Run the code above in your browser using DataLab