| scale_edge_widths_simple | R Documentation |
Simple linear edge width scaling used by sn_edges() when width="weight". For the full-featured version with multiple modes and cut parameter, see scale_edge_widths() in scale-constants.R.
scale_edge_widths_simple(values, range = c(0.5, 3), maximum = NULL)
values |
Numeric values to scale. |
range |
Target width range (min, max). |
maximum |
Optional maximum value for scaling. If provided, this value maps to the max of range, and values above it are capped. |
Scaled width values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.