View source: R/class-network.R
| set_layout | R Documentation |
Sets the layout coordinates in a cograph_network object. Updates the x and y columns in the nodes data frame.
set_layout(x, layout_df)
x |
A cograph_network object. |
layout_df |
A data frame with x and y columns, or a matrix with 2 columns. |
The modified cograph_network object.
as_cograph, get_nodes, sn_layout
mat <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), nrow = 3)
net <- as_cograph(mat)
layout <- data.frame(x = c(0, 1, 0.5), y = c(0, 0, 1))
net <- set_layout(net, layout)
get_nodes(net)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.