Learn R Programming

cograph (version 1.5.2)

set_layout: Set Layout in Cograph Network

Description

Sets the layout coordinates in a cograph_network object. Updates the x and y columns in the nodes data frame.

Usage

set_layout(x, layout_df)

Value

The modified cograph_network object.

Arguments

x

A cograph_network object.

layout_df

A data frame with x and y columns, or a matrix with 2 columns.

See Also

as_cograph, get_nodes, sn_layout

Examples

Run this code
mat <- matrix(c(0, 1, 1, 1, 0, 1, 1, 1, 0), nrow = 3)
net <- as_cograph(mat)
layout <- data.frame(x = c(0, 1, 0.5), y = c(0, 0, 1))
net <- set_layout(net, layout)
get_nodes(net)

Run the code above in your browser using DataLab