View source: R/plot-nestimate.R
| splot.netobject | R Documentation |
Applies TNA-compatible styling defaults before delegating to splot():
directed networks get oval layout, coloured nodes, and sized arrows;
undirected networks get spring layout with no arrows or dashes.
All parameters can be overridden by the caller.
splot.netobject(x, ...)
x |
A |
... |
Additional arguments passed to |
Invisibly returns the plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.